jan: thuban/Extensions/importAPR __init__.py,1.1,1.2

cvs@intevation.de cvs at intevation.de
Sat Nov 20 13:54:38 CET 2004


Author: jan

Update of /thubanrepository/thuban/Extensions/importAPR
In directory doto:/tmp/cvs-serv3798

Modified Files:
	__init__.py 
Log Message:
Added registry entry and the importing
of the actual importAPR module.


Index: __init__.py
===================================================================
RCS file: /thubanrepository/thuban/Extensions/importAPR/__init__.py,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- __init__.py	22 Sep 2003 10:45:57 -0000	1.1
+++ __init__.py	20 Nov 2004 12:54:36 -0000	1.2
@@ -1,6 +1,21 @@
-# Copyright (c) 2003 by Intevation GmbH
+# Copyright (c) 2003, 2004 by Intevation GmbH
 # Authors:
 # Jan-Oliver Wagner <jan at intevation.de>
 #
 # This program is free software under the GPL (>=v2)
 # Read the file COPYING coming with Thuban for details.
+
+# import the actual module
+import importAPR
+
+# perform the registration of the extension
+from Thuban import _
+from Thuban.UI.extensionregistry import ExtensionDesc, ext_registry
+
+ext_registry.add(ExtensionDesc(
+    name = 'importAPR',
+    version = '0.1.1',
+    authors= [ 'Jan-Oliver Wagner' ],
+    copyright = '2003, 2004 Intevation GmbH',
+    desc = _("Import a ArcView project file (.apr)\n" \
+             "and convert it to Thuban.")))
@@ -1,6 +1,21 @@
 # Authors:
-# Jan-Oliver Wagner <jan at intevation.de>
+# Jan-Oliver Wagner <jan at intevation.de> (2003, 2004)
 #
 # This program is free software under the GPL (>=v2)





More information about the Thuban-devel mailing list

This site is hosted by Intevation GmbH (Datenschutzerklärung und Impressum | Privacy Policy and Imprint)